==> haskell-hls-cabal-plugin-2.1.0.0-100-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-cabal-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-cabal-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-cabal-plugin-2.1.0.0-DMwGWBQgwvg7iFoXNI69dV
key:                  hls-cabal-plugin-2.1.0.0-DMwGWBQgwvg7iFoXNI69dV
license:              MIT
maintainer:           fendor@posteo.de
author:               Fendor
synopsis:             Cabal integration plugin with Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  34c2681f333ddd003861c8326687c884
exposed:              True
exposed-modules:
    Ide.Plugin.Cabal Ide.Plugin.Cabal.Completion.Completer.FilePath
    Ide.Plugin.Cabal.Completion.Completer.Module
    Ide.Plugin.Cabal.Completion.Completer.Simple
    Ide.Plugin.Cabal.Completion.Completer.Snippet
    Ide.Plugin.Cabal.Completion.Completer.Types
    Ide.Plugin.Cabal.Completion.Completions
    Ide.Plugin.Cabal.Completion.Data Ide.Plugin.Cabal.Completion.Types
    Ide.Plugin.Cabal.Diagnostics Ide.Plugin.Cabal.LicenseSuggest
    Ide.Plugin.Cabal.Parse

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-cabal-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-cabal-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-cabal-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-cabal-plugin
hs-libraries:         HShls-cabal-plugin-2.1.0.0-DMwGWBQgwvg7iFoXNI69dV
depends:
    Cabal-syntax-3.10.3.0 base-4.18.2.1 bytestring-0.11.5.3
    containers-0.6.7 deepseq-1.4.8.1 directory-1.3.8.5
    extra-1.7.16-3o8MjPiNQTlLg74BSenHLy filepath-1.4.300.1
    ghcide-2.1.0.0-FnivsoqaY804ocwiGSGs4S
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    hls-graph-2.1.0.0-2K7OAPbw31L8NzoSrWGIDe
    hls-plugin-api-2.1.0.0-DLt74c0m6zn5iIl3F9hXDn
    lens-5.3.3-HAYf6JaG0qX5o8D7xn9NgM
    lsp-2.1.0.0-FDkJ3hOfaOyD0G3xXwdyeX
    lsp-types-2.0.1.0-KsWoulY9wwoKMSLEqbLHCK
    regex-tdfa-1.3.2.5-ATqtlBuPETHJOcVIKuiav2 stm-2.5.1.0 text-2.0.2
    text-rope-0.3-Gq8oRIBjiYqAbKRkuHVfVA transformers-0.6.1.0
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu

haddock-interfaces:
    /usr/share/doc/haskell-hls-cabal-plugin/html/hls-cabal-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-cabal-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-cabal-plugin-2.1.0.0-102-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-cabal-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-cabal-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-cabal-plugin-2.1.0.0-FKIoe1Y3VKfJN1oJnHgRze
key:                  hls-cabal-plugin-2.1.0.0-FKIoe1Y3VKfJN1oJnHgRze
license:              MIT
maintainer:           fendor@posteo.de
author:               Fendor
synopsis:             Cabal integration plugin with Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  b9e3703de471b4cc1e927b21d034e307
exposed:              True
exposed-modules:
    Ide.Plugin.Cabal Ide.Plugin.Cabal.Completion.Completer.FilePath
    Ide.Plugin.Cabal.Completion.Completer.Module
    Ide.Plugin.Cabal.Completion.Completer.Simple
    Ide.Plugin.Cabal.Completion.Completer.Snippet
    Ide.Plugin.Cabal.Completion.Completer.Types
    Ide.Plugin.Cabal.Completion.Completions
    Ide.Plugin.Cabal.Completion.Data Ide.Plugin.Cabal.Completion.Types
    Ide.Plugin.Cabal.Diagnostics Ide.Plugin.Cabal.LicenseSuggest
    Ide.Plugin.Cabal.Parse

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-cabal-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-cabal-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-cabal-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-cabal-plugin
hs-libraries:         HShls-cabal-plugin-2.1.0.0-FKIoe1Y3VKfJN1oJnHgRze
depends:
    Cabal-syntax-3.10.3.0 base-4.18.2.1 bytestring-0.11.5.3
    containers-0.6.7 deepseq-1.4.8.1 directory-1.3.8.5
    extra-1.7.16-IkudFHstV64EKMSGT8IWWb filepath-1.4.300.1
    ghcide-2.1.0.0-FpGXYcNEFHuE24CSyfyNdp
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    hls-graph-2.1.0.0-LgEicARMXCt6QmF6Vp3LRx
    hls-plugin-api-2.1.0.0-BfiKLSupfw45UdhJj6iHuY
    lens-5.3.3-GI3kNGpcyiIBMdla72MFoB lsp-2.1.0.0-jiZ0SP1Jku9ft66mbKdaK
    lsp-types-2.0.1.0-16awFyiKGg1Iy6lHArG7S3
    regex-tdfa-1.3.2.5-EWGvfiHhNcof6jXGuIJ2K stm-2.5.1.0 text-2.0.2
    text-rope-0.3-7UnKSGc2q389N6WPFXjNKl transformers-0.6.1.0
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5

haddock-interfaces:
    /usr/share/doc/haskell-hls-cabal-plugin/html/hls-cabal-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-cabal-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
